@@ -1,21 +1,47 @@
 package Throwable;
-{
-  $Throwable::VERSION = '0.200008';
-}
+# ABSTRACT: a role for classes that can be thrown
+$Throwable::VERSION = '0.200010';
 use Moo::Role;
 use Sub::Quote ();
 use Scalar::Util ();
 use Carp ();
 
-# ABSTRACT: a role for classes that can be thrown
-
+# =head1 SYNOPSIS
+#
+#   package Redirect;
+#   use Moose;
+#   with 'Throwable';
+#
+#   has url => (is => 'ro');
+#
+# ...then later...
+#
+#   Redirect->throw({ url => $url });
+#
+# =head1 DESCRIPTION
+#
+# Throwable is a role for classes that are meant to be thrown as exceptions to
+# standard program flow.  It is very simple and does only two things: saves any
+# previous value for C<$@> and calls C<die $self>.
+#
+# Throwable is implemented with L<Moo>, so you can stick to Moo or use L<Moose>
+# as you prefer.
+#
+# =attr previous_exception
+#
+# This attribute is created automatically, and stores the value of C<$@> when the
+# Throwable object is created.  This is done on a I<best effort basis>.  C<$@> is
+# subject to lots of spooky action-at-a-distance.  For now, there are clearly
+# ways that the previous exception could be lost.
+#
+# =cut
 
 our %_HORRIBLE_HACK;
 
 has 'previous_exception' => (
   is       => 'ro',
   default  => Sub::Quote::quote_sub(q<
-    if ($Throwable::_HORRIBLE_HACK{ERROR}) {
+    if (defined $Throwable::_HORRIBLE_HACK{ERROR}) {
       $Throwable::_HORRIBLE_HACK{ERROR}
     } elsif (defined $@ and (ref $@ or length $@)) {
       $@;
@@ -25,6 +51,16 @@ has 'previous_exception' => (
   >),
 );
 
+# =method throw
+#
+#   Something::Throwable->throw({ attr => $value });
+#
+# This method will call new, passing all arguments along to new, and will then
+# use the created object as the only argument to C<die>.
+#
+# If called on an object that does Throwable, the object will be rethrown.
+#
+# =cut
 
 sub throw {
   my ($inv) = shift;
@@ -46,13 +82,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Throwable - a role for classes that can be thrown
 
 =head1 VERSION
 
-version 0.200008
+version 0.200010
 
 =head1 SYNOPSIS
 
@@ -72,6 +110,9 @@ Throwable is a role for classes that are meant to be thrown as exceptions to
 standard program flow.  It is very simple and does only two things: saves any
 previous value for C<$@> and calls C<die $self>.
 
+Throwable is implemented with L<Moo>, so you can stick to Moo or use L<Moose>
+as you prefer.
+
 =head1 ATTRIBUTES
 
 =head2 previous_exception
@@ -108,7 +149,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
